@@ -12,6 +12,14 @@ from sklearn.neighbors import KNeighborsClassifier
 from pneuro.appLogger import AppLogger
 from pneuro.file_methods import FileOperation
 
+import pathlib
+
+# The directory containing this file
+HERE = pathlib.Path(__file__).parent
+# The text of the README file
+classificationTrainingLogs = HERE / "logs" / "classificationTrainingLogs.txt"
+
+
 class ClassificationModelTuner():
     """
         This class shall be used to get the best suited classification model
@@ -23,7 +31,8 @@ class ClassificationModelTuner():
         """
 
     def __init__(self):
-        self.file_object = open('pneuro/logs/classificationTrainingLogs.txt', 'a+')
+        # self.file_object = open('pneuro/logs/classificationTrainingLogs.txt', 'a+')
+        self.file_object = open(classificationTrainingLogs, 'a+')
         self.logger_object = AppLogger()
         self.file_operation = FileOperation()
 
@@ -307,4 +316,4 @@ class ClassificationModelTuner():
                                        e))
             self.logger_object.log(self.file_object,
                                    'Model Selection Failed. Exited the generate_model_report method of the ClassificationModelTuner class')
-            raise Exception()
\ No newline at end of file
+            raise Exception()
