@@ -9,7 +9,12 @@ from sklearn.preprocessing import LabelEncoder
 from sklearn.preprocessing import MinMaxScaler
 
 from pneuro.appLogger import AppLogger
+import pathlib
 
+# The directory containing this file
+HERE = pathlib.Path(__file__).parent
+# The text of the README file
+dataPreprocessingLogs = HERE/"logs"/"dataPreprocessingLogs.txt"
 
 class Preprocessor():
     """
@@ -23,7 +28,8 @@ class Preprocessor():
     """
 
     def __init__(self):
-        self.file_object = open('pneuro/logs/dataPreprocessingLogs.txt', 'a+')
+        #self.file_object = open('pneuro/logs/dataPreprocessingLogs.txt', 'a+')
+        self.file_object = open(dataPreprocessingLogs, 'a+')
         self.logger_object = AppLogger()
 
     def get_data_profile(self, data):
