@@ -3,6 +3,14 @@ import os
 from pneuro.file_methods import FileOperation
 from pneuro.appLogger import AppLogger
 from pneuro.preProcess import Preprocessor
+import pathlib
+
+# The directory containing this file
+HERE = pathlib.Path(__file__).parent
+# The text of the README file
+predictionLogs = HERE / "logs" / "predictionLogs.txt"
+
+
 class CustomException(Exception):
     pass
 
@@ -27,7 +35,8 @@ class Prediction():
                         Revisions: None
 
                 """
-        self.file_object = open('pneuro/logs/predictionLogs.txt', 'a+')
+        #self.file_object = open('pneuro/logs/predictionLogs.txt', 'a+')
+        self.file_object = open(predictionLogs, 'a+')
         self.logger = AppLogger()
         self.file_operation = FileOperation()
         self.models_directory = 'models'
