@@ -7,6 +7,12 @@ import xgboost as xgb
 from sklearn.neighbors import KNeighborsRegressor
 from pneuro.appLogger import AppLogger
 from pneuro.file_methods import FileOperation
+import pathlib
+
+# The directory containing this file
+HERE = pathlib.Path(__file__).parent
+# The text of the README file
+RegressionTrainingLogs = HERE/"logs"/"RegressionTrainingLogs.txt"
 
 class RegressionModelTuner():
     """
@@ -19,7 +25,8 @@ class RegressionModelTuner():
     """
 
     def __init__(self):
-        self.file_object = open('pneuro/logs/RegressionTrainingLogs.txt', 'a+')
+        #self.file_object = open('pneuro/logs/RegressionTrainingLogs.txt', 'a+')
+        self.file_object = open(RegressionTrainingLogs, 'a+')
         self.logger_object = AppLogger()
         self.file_operation = FileOperation()
 
