@@ -11,6 +11,12 @@ import numpy as np
 import seaborn as sns
 
 from pneuro.appLogger import AppLogger
+import pathlib
+
+# The directory containing this file
+HERE = pathlib.Path(__file__).parent
+# The text of the README file
+dataVisualizationLogs = HERE/"logs"/"dataVisualizationLogs.txt"
 
 
 class DataVisualization:
@@ -24,7 +30,8 @@ class DataVisualization:
     """
 
     def __init__(self):
-        self.file_object = open('pneuro/logs/dataVisualizationLogs.txt', 'a+')
+        #self.file_object = open('pneuro/logs/dataVisualizationLogs.txt', 'a+')
+        self.file_object = open(dataVisualizationLogs, 'a+')
         self.logger_object = AppLogger()
 
     def balance_imbalance_check(self, dataframe, target):
